@@ -1,4 +1,4 @@
-import pandas as include_package_data
+import pandas as pd
 
 def load_manzana_data():
     return pd.read_csv("data/reduced_data_MinMaxScaler_PCA_manzana_224.csv")
\ No newline at end of file
